@@ -5,18 +5,22 @@ use strict;
 use warnings;
 
 # ABSTRACT: An EXPERIMENTAL subclass of <Exporter::Extensible>, which helps create easy-to-extend modules that export symbols
-our $VERSION = '1.000000';
+our $VERSION = '1.000001';
 
 use Exporter::Extensible -exporter_setup => 1;
 
-sub xtags : Export {
+# Generators for exported functions
+sub _generate_xtags : Export(=xtags) {
   require Exporter::Handy::Util;
-  Exporter::Handy::Util::xtags({ sig => ':' }, @_)
+  my ($exporter, $symbol, $opts) = @_;
+  my %opts = ( sig => ':',  %{; $opts // {} } );
+  sub {; Exporter::Handy::Util::xtags( \%opts, @_ ) } # curried
 }
 
-sub expand_xtags : Export {
+sub _generate_expand_xtags : Export(=expand_xtags) {
   require Exporter::Handy::Util;
-  Exporter::Handy::Util::expand_xtags(@_)
+  my ($exporter, $symbol, $opts) = @_;
+  sub {; Exporter::Handy::Util::expand_xtags(@_, $opts // { }) } # curried
 }
 
 
@@ -110,7 +114,7 @@ Exporter::Handy - An EXPERIMENTAL subclass of <Exporter::Extensible>, which help
 
 =head1 VERSION
 
-version 1.000000
+version 1.000001
 
 =head1 SYNOPSIS
 
